<?php

namespace Ebuy\Discount\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Ebuy\Discount\Interfaces\DiscountRepositoryInterface;
use Ebuy\Discount\Repositories\Eloquent\Filters\DiscountPublicFilter;
use Ebuy\Discount\Repositories\Eloquent\Presenters\DiscountListPresenter;

class DiscountPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        DiscountRepositoryInterface $discount
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.discount.modules'), 'discount', guard_url('discount'));
        $this->repository = $discount;
    }

    /**
     * Show discount's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(DiscountPublicFilter::class)
            ->setPresenter(DiscountListPresenter::class)
            ->select('discounts.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('discount::discount.names'))
            ->view('discount::public.discount.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show discount.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('discount::discount.name'))
            ->view('discount::public.discount.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
