<?php

namespace Ebuy\Discount\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ebuy\Discount\Models\Discount;

class DiscountPolicy
{

    /**
     * Determine if the given user can view the discount.
     *
     * @param UserPolicyInterface $authUser
     * @param Discount $discount
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Discount $discount)
    {
        if ($authUser->canDo('discount.discount.view') && $authUser->isAdmin()) {
            return true;
        }

        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can create a discount.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('discount.discount.create');
    }

    /**
     * Determine if the given user can update the given discount.
     *
     * @param UserPolicyInterface $authUser
     * @param Discount $discount
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Discount $discount)
    {
        if ($authUser->canDo('discount.discount.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given discount.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Discount $discount)
    {
        return $discount->user_id == user_id() && $discount->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given discount.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Discount $discount)
    {
        if ($authUser->canDo('discount.discount.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given discount.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Discount $discount)
    {
        if ($authUser->canDo('discount.discount.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
